# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   interfaceAutoTest_v4
# FileName:      request_method.py
# Author:       ALuo
# Datetime:     2023/11/6 9:57
# Description:  统一请求方法
# ---------------------------------------------------------------------------
import base64

import requests

from interfaceAutoTest.common import alog
from interfaceAutoTest.common.read_ini import ReadIni
from interfaceAutoTest.data_config.setting import *


class RequestMethod:

    def __init__(self):
        # 关联登录状态
        read_ini = ReadIni()
        login_data = {"username": "admin", "password": base64.b64encode("123456".encode()).decode()}
        login_url = read_ini.get_host(Test_Host) + "/auth"

        # session对象
        self.req_session = requests.sessions.Session()
        res_session = self.req_session.post(url=login_url, json=login_data)
        self.req_session.headers["Authorization"] ="Bearer " + res_session.json()["token"]

    def request_all(self, method, url, mime=None, case_data=None):
        if mime is None:
            return self.req_session.request(method=method, url=url)
        elif mime in ("application/json", "json", "body"):
            return self.req_session.request(method=method, url=url, json=case_data)
        elif mime in ("application/x-www-form-urlencoded", "x-www-form-urlencoded", "form"):
            return self.req_session.request(method=method, url=url, data=case_data)
        elif mime in ("query", "params", "param"):
            return self.req_session.request(method=method, url=url, params=case_data)
        elif mime in ("query|body", "body|query", "json|query", "query|json"):
            return self.req_session.request(method=method, url=url, params=case_data["query"], json=case_data["body"])
        elif mime in ("form-data", "multipart/form-data"):
            return self.req_session.request(method=method, url=url, files=case_data)
        else:
            alog.error("传入的媒体类型的值错误，请察看excel中是否填入正确")
            raise NameError("传入的媒体类型的值错误，请察看excel中是否填入正确")

if __name__ == '__main__':
    request_all = RequestMethod()
